# To recreate figures and tables in main text simply run this script
# Outputs figures as pdf files and tables as tex files
# Figure and table numbering of output as in article

##### Load required packages, read in dataset, create helper functions #####
library(DeclareDesign)
library(ggplot2)
library(scales)
library(stargazer)
library(dplyr)
df <- read.csv('data.csv')
df$group <- as.factor(df$group)
df$topic <- as.factor(df$topic)
dm <- difference_in_means # Difference-in-means estimator from DeclareDesign
# Helper function that extracts relevant information from difference_in_means
# output for use in stargazer
combine_models <- function(models, ind = NULL){
  nmodels <- length(models)
  dft <- data.frame(coef = numeric(nmodels),
                    se = numeric(nmodels),
                    p = numeric(nmodels))
  for (i in 1:nmodels){
    dft[i,] <- c(models[[i]]$coefficients,
                 models[[i]]$std.error,
                 models[[i]]$p.value)
  }
  df <- dft
  if (!is.null(ind)){
    nind     <- length(ind)
    df       <- data.frame(coef = NA * numeric(nind),
                           se = NA * numeric(nind),
                           p = NA * numeric(nind))
    df[ind,] <- dft
  }
  return(df)
}


##### Plot Figure 3 #####
gl  <- geom_line(aes(color = sample, size = sample), show.legend = FALSE)
gp  <- geom_point(aes(color = sample, size = sample))
sx  <- scale_x_discrete(breaks = c(1, 2, 3),
                        expand = c(0.15, 0.15),
                        labels = c('Control', 'Rumour', 'Rebuttal'))
sy  <- scale_y_continuous(breaks = c(1, 2, 3, 4, 5),
                          expand = c(0, 0),
                          limits = c(1, 5.5),
                          oob = rescale_none)
sf  <- scale_color_manual(values = c('#A7A7A7', '#E6E6E6', '#000000'),
                        labels = c('Pan-Blue', 'Pan-Green', 'Full Sample'),
                        drop = FALSE)
ss  <- scale_size_manual(values = c(0.5, 0.5, 1.5))
gu  <- guides(color = guide_legend(reverse = TRUE), size = FALSE)
tm  <- theme(panel.background = element_blank(),
             strip.background = element_blank(),
             panel.spacing = unit(2, "lines"),
             axis.title.x = element_blank(),
             axis.title.y = element_text(size = 8),
             legend.position = 'top',
             legend.title = element_blank(),
             legend.key = element_rect(fill = NA),
             legend.key.size = unit(10, 'pt'))

# Credibility of Rumor
dft  <- df %>% filter(group!=1)
df1  <- dft %>% group_by(group) %>% summarize(mean_app = mean(credibility))
df2  <- dft %>% filter(pan_green==1) %>% group_by(group) %>% 
  summarize(mean_app = mean(credibility))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_app = mean(credibility))
dft  <- bind_rows(df1, df2, df3)
dftt <- mutate(dft, sample = as.factor(c(1, 1, 2, 2, 3, 3)))

# Mainland Government Approval
dft  <- df %>% filter(app_main %in% seq(1, 7))
df1  <- dft %>% group_by(group) %>% summarize(mean_app=mean(app_main))
df2  <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_main))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_main))
dft  <- bind_rows(df1, df2, df3)
dft  <- mutate(dft, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))
dftt <- bind_rows(dftt, dft)

# Independence Approval
dft  <- df %>% filter(app_indep %in% seq(1, 7))
df1  <- dft %>% group_by(group) %>% summarize(mean_app = mean(app_indep))
df2  <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_indep))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_indep))
dft  <- bind_rows(df1, df2, df3)
dft  <- mutate(dft, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))
dftt <- bind_rows(dftt, dft)

# DPP Approval
dft  <- df %>% filter(app_dpp %in% seq(1, 7))
df1  <- dft %>% group_by(group) %>% summarize(mean_app = mean(app_dpp))
df2  <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_dpp))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_dpp))
dft  <- bind_rows(df1, df2, df3)
dft  <- mutate(dft, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))
dftt <- bind_rows(dftt, dft)

# KMT Approval
dft  <- df %>% filter(app_kmt %in% seq(1, 7))
df1  <- dft %>% group_by(group) %>% summarize(mean_app = mean(app_kmt))
df2  <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_kmt))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_app = mean(app_kmt))
dft  <- bind_rows(df1, df2, df3)
dft  <- mutate(dft, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))
dftt <- bind_rows(dftt, dft)

outcome1 <- rep('Credibility', 6)
outcome2 <- rep(c('Approval Mainland', 'Approval Independence', 'Approval DPP',
                  'Approval KMT'), each = 9)
outcome  <- c(outcome1, outcome2)
dftt <- mutate(dftt, outcome = factor(outcome, levels = unique(outcome)))
dftt$sample <- factor(dftt$sample, c('3', '2', '1'))

# Create figure
fig <- ggplot(dftt, aes(x = group, y = mean_app, group = sample)) +
  gl + gp + sx + sy + sf + ss + gu + tm + facet_wrap(~outcome, ncol = 5) +
  labs(y = 'Mean')

ggsave(file = 'figure3.pdf', plot = fig, width = 9, height = 5)


##### Compute results for Table 1 #####

# Effect on Credibility
## Full Sample
modf <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3) # Rebuttal - Rumor
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modf, modg, modb),
                           c(F, F, T, F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Full Sample
mod1f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
mod1f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_indep ~ group, data=df, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Full Sample
mod1f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Full Sample
mod1f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
p     <- list(m1 = mod_cred$p, m2 = mod_main$p, m3 = mod_indep$p,
              m4 = mod_dpp$p, m5 = mod_kmt$p)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'table1.tex', out.header = T)


##### Compute results for Table 2 #####
dft <- df
dft$income <- na_if(dft$income, 98)
dft$nat_id <- recode(dft$nat_id, '1' = 1, '2' = 0, '3' = 0, '98' = 0)

# Effect on Mainland Government Approval
mod1 <- lm(app_main ~ I(group==2) + I(group==3) + pan_green + pan_blue + age +
             gender + income + education + nat_id, data = dft)
# Effect on Independence Approval
mod2 <- lm(app_indep ~ I(group==2) + I(group==3) + pan_green + pan_blue + age +
             gender + income + education + nat_id, data = dft)
# Effect on DPP Approval
mod3 <- lm(app_dpp ~ I(group==2) + I(group==3) + pan_green + pan_blue + age +
             gender + income + education + nat_id, data = dft)
# Effect on KMT Approval
mod4 <- lm(app_kmt ~ I(group==2) + I(group==3) + pan_green + pan_blue + age +
             gender + income + education + nat_id, data = dft)

# Create table
column.labels <- c('Mainland', 'Independence', 'DPP', 'KMT')
covariate.labels <- c('Rumor', 'Rebuttal')
omit <- c('pan_green', 'pan_blue', 'age', 'gender', 'income', 'education', 'nat_id', 'Constant')
omit.stat <- c('adj.rsq', 'f', 'ser')
stargazer(mod1, mod2, mod3, mod4, column.labels = column.labels,
          covariate.labels = covariate.labels, dep.var.caption = '',
          dep.var.labels.include = F, model.numbers = F, omit = omit,
          omit.stat = omit.stat, out = 'table2.tex', out.header = T)


##### Plot Figure 4 #####
sy  <- scale_y_continuous(breaks = c(0, 0.5, 1),
                          expand = c(0, 0),
                          limits = c(0, 1.1),
                          oob = rescale_none)

dft            <- df
dft$view_main1 <- recode(dft$view_main1, '1' = 0, '2' = 1, '3' = 0, '98' = 0)
dft$view_twgov <- recode(dft$view_twgov, '1' = 0, '2' = 1, '3' = 0, '98' = 0)

# Affect views of mainland
df1   <- dft %>% group_by(group) %>% summarize(mean_aff = mean(view_main1))
df2   <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_aff = mean(view_main1))
df3   <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_aff = mean(view_main1))
dftt  <- bind_rows(df1, df2, df3)
dfttt <- mutate(dftt, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))

# Affect views of Taiwanese government
df1   <- dft %>% group_by(group) %>% summarize(mean_aff = mean(view_twgov))
df2   <- dft %>% filter(pan_green==1) %>% group_by(group) %>%
  summarize(mean_aff = mean(view_twgov))
df3   <- dft %>% filter(pan_blue==1) %>% group_by(group) %>%
  summarize(mean_aff = mean(view_twgov))
dftt  <- bind_rows(df1, df2, df3)
dftt  <- mutate(dftt, sample = as.factor(c(1, 1, 1, 2, 2, 2, 3, 3, 3)))
dfttt <- bind_rows(dfttt, dftt)

outcome <- rep(c('Mainland', 'Taiwanese Government'), each = 9)
dfttt   <- mutate(dfttt, outcome = factor(outcome, levels = unique(outcome)))
dfttt$sample <- factor(dfttt$sample, c('3', '2', '1'))
dfttt        <- dfttt %>% arrange(sample)

# Create figure
fig <- ggplot(dfttt, aes(x = group, y = mean_aff, group = sample)) +
  gl + gp + sx + sy + sf + ss + gu + tm + facet_wrap(~outcome, ncol = 2) +
  labs(y = 'Proportion')

ggsave(file = 'figure4.pdf', plot = fig, width = 4, height = 3)


##### Plot Figure 5 #####
labels1 <- c('Negative Prior', 'Personal Skill', 'General Distrust')
labels2 <- c('Autonomy', 'Political System', 'Social Cohesion',
             'Distrust Mainland')
gc <- geom_col(position = position_dodge(width = 0.95))
sx1 <- scale_x_discrete(breaks = c(5, 6, 7),
                        expand = c(0.15, 0.15),
                        labels = labels1)
sx2 <- scale_x_discrete(breaks = c(1, 2, 3, 4),
                        expand = c(0.15, 0.15),
                        labels = labels2)
sy1 <- scale_y_continuous(breaks = c(0, 0.3, 0.6),
                          expand = c(0,0),
                          limits = c(0,0.6),
                          oob = rescale_none)
sy2 <- scale_y_continuous(breaks = c(0, 0.1, 0.2),
                          expand = c(0,0),
                          limits = c(0,0.2),
                          oob = rescale_none)
sf  <- scale_fill_grey(start = 0.9,
                        end = 0.45,
                        labels = c('Pan-Green', 'Pan-Blue'),
                        drop = TRUE)

# Opinion not affected
dft  <- df %>% filter(view_main2==0)
n99f <- sum(dft$topic==99)
n99g <- sum(dft$topic==99 & dft$pan_green==1)
n99b <- sum(dft$topic==99 & dft$pan_blue==1)
dft  <- dft %>% filter(topic!=99)
df2  <- dft %>% filter(pan_green==1) %>% group_by(topic) %>%
  summarize(freq_top = sum(topic==topic)) %>%
  mutate(freq_top = freq_top / (sum(freq_top) + n99g))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(topic) %>%
  summarize(freq_top = sum(topic==topic)) %>%
  mutate(freq_top = freq_top / (sum(freq_top) + n99b))
dftt <- bind_rows(df2, df3)
dftt <- mutate(dftt, sample = factor(c(1, 1, 1, 2, 2, 2)))
dftt        <- dftt %>% arrange(sample)
# Create figure
fig1 <- ggplot(dftt, aes(x = topic, y = freq_top, fill = sample)) +
  gc + sx1 + sy1 + sf + ss + gu + tm + labs(y = 'Topic Proportions') 

ggsave(file = 'figure5a.pdf', plot = fig1, width = 5, height = 3)

# Opinion affected
dft  <- df %>% filter(view_main2==1)
n99f <- sum(dft$topic==99)
n99g <- sum(dft$topic==99 & dft$pan_green==1)
n99b <- sum(dft$topic==99 & dft$pan_blue==1)
dft  <- dft %>% filter(topic!=99)
df2  <- dft %>% filter(pan_green==1) %>% group_by(topic) %>%
  summarize(freq_top = sum(topic==topic)) %>%
  mutate(freq_top = freq_top / (sum(freq_top) + n99g))
df3  <- dft %>% filter(pan_blue==1) %>% group_by(topic) %>%
  summarize(freq_top = sum(topic==topic)) %>%
  mutate(freq_top = freq_top / (sum(freq_top) + n99b))
dftt <- bind_rows(df2, df3)
dftt <- mutate(dftt, sample = factor(c(1, 1, 1, 1, 2, 2, 2, 2)))
dftt        <- dftt %>% arrange(sample)
# Create figure
fig2 <- ggplot(dftt, aes(x = topic, y = freq_top, fill = sample)) +
  gc + sx2 + sy2 + sf + ss + gu + tm + labs(y = 'Topic Proportions') 

ggsave(file = 'figure5b.pdf', plot = fig2, width = 5, height = 3)

