# To recreate figures and tables in the supplementary appendix simply run 
# this script
# Outputs figures as pdf files and tables as tex files
# Figure and table numbering as in article

##### Load required packages, read in dataset, create helper functions #####
library(DeclareDesign)
library(ggplot2)
library(scales)
library(stargazer)
library(dplyr)
library(MASS)
df <- read.csv('data.csv')
df$group <- as.factor(df$group)
df$topic <- as.factor(df$topic)
dm <- difference_in_means # Difference-in-means estimator from DeclareDesign
# Helper function that extracts relevant information from difference_in_means
# output for use in stargazer
combine_models <- function(models, ind = NULL){
  nmodels <- length(models)
  dft <- data.frame(coef = numeric(nmodels),
                    se = numeric(nmodels),
                    p = numeric(nmodels))
  for (i in 1:nmodels){
    dft[i,] <- c(models[[i]]$coefficients,
                 models[[i]]$std.error,
                 models[[i]]$p.value)
  }
  df <- dft
  if (!is.null(ind)){
    nind     <- length(ind)
    df       <- data.frame(coef = NA * numeric(nind),
                           se = NA * numeric(nind),
                           p = NA * numeric(nind))
    df[ind,] <- dft
  }
  return(df)
}


##### Compute results for Table B.1; with Bonferroni Correction #####

# Effect on Credibility
## Full Sample
modf <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3) # Rebuttal - Rumor
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modf, modg, modb),
                           c(F, F, T, F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Full Sample
mod1f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
mod1f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_indep ~ group, data=df, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Full Sample
mod1f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Full Sample
mod1f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
# Bonferroni corrected p-values.
# Correction factor: 10 = 5 outcomes (Approval Mainland, Independence, DPP,
# KMT,USA) * 2 independent comparisons (Rumor vs Control & Rebuttal vs Control)
padj  <- list(m1 = mod_cred$p, m2 = mod_main$p * 10, m3 = mod_indep$p * 10,
              m4 = mod_dpp$p * 10, m5 = mod_kmt$p * 10)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')

stargazer(mods, coef = coef, se = se, p = padj,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB1.tex', out.header = T)


##### Compute results for Table B.2; not seen rumor or rebuttal #####
dfmain <- df
df     <- filter(df, seen_rumor!=1 | is.na(seen_rumor), 
                 seen_rebuttal!=1 | is.na(seen_rebuttal))

# Effect on Credibility
## Full Sample
modf <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3) # Rebuttal - Rumor
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modf, modg, modb),
                           c(F, F, T, F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Full Sample
mod1f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
mod1f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_indep ~ group, data=df, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Full Sample
mod1f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Full Sample
mod1f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))



# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
p     <- list(m1 = mod_cred$p, m2 = mod_main$p, m3 = mod_indep$p,
              m4 = mod_dpp$p, m5 = mod_kmt$p)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB2.tex', out.header = T)

df <- dfmain


##### Compute results for Table B.3; DPP, KMT subsamples #####
dfmain       <- df
df$pan_green <- df$party_id==2
df$pan_blue  <- df$party_id==1

# Effect on Credibility
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modg, modb), c(F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1g, mod2g, mod3g, mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1g, mod2g, mod3g, mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1g, mod2g, mod3g, mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1g, mod2g, mod3g, mod1b, mod2b, mod3b))


# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f')
d           <- as.data.frame(matrix(rnorm(20 * 6), nc = 7))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
p     <- list(m1 = mod_cred$p, m2 = mod_main$p, m3 = mod_indep$p,
              m4 = mod_dpp$p, m5 = mod_kmt$p)

covariate.labels <- c('Rumor vs Control (G)', 'Rebuttal vs Control (G)',
                      'Rebuttal vs Rumor (G)', 'Rumor vs Control (B)',
                      'Rebuttal vs Control (B)', 'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB3.tex', out.header = T)

df <- dfmain


##### Compute results for Table B.4; no university education #####
dfmain <- df
df     <- filter(df, education<6)

# Effect on Credibility
## Full Sample
modf <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3) # Rebuttal - Rumor
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modf, modg, modb),
                           c(F, F, T, F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Full Sample
mod1f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
mod1f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_indep ~ group, data=df, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Full Sample
mod1f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Full Sample
mod1f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
p     <- list(m1 = mod_cred$p, m2 = mod_main$p, m3 = mod_indep$p,
              m4 = mod_dpp$p, m5 = mod_kmt$p)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB4.tex', out.header = T)

df <- dfmain


##### Compute Results for Table B.5; excluding low effort ######
dfmain <- df
df     <- filter(df, low_effort!=1)

# Effect on Credibility
## Full Sample
modf <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3) # Rebuttal - Rumor
## Pan-Green
modg <- dm(credibility ~ group, data = df, condition1 = 2,
           condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
modb <- dm(credibility ~ group, data = df, condition1 = 2, condition2 = 3,
           subset = pan_blue==1) # Rebuttal - Rumor

mod_cred <- combine_models(list(modf, modg, modb),
                           c(F, F, T, F, F, T, F, F, T))

# Effect on Mainland Government Approval
## Full Sample
mod1f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_main ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_main ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                mod1b, mod2b, mod3b))

# Effect on Independence Approval
## Full Sample
mod1f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_indep ~ group, data=df, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_indep ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_indep ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_indep <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Effect on DPP Approval
## Full Sample
mod1f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_dpp ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_dpp ~ group, data = df, condition1 = 1, 
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_dpp ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_dpp <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Effect on KMT Approval
## Full Sample
mod1f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(app_kmt ~ group, data = df, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(app_kmt ~ group, data = df, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_kmt <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                               mod1b, mod2b, mod3b))

# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- m3 <- m4 <- m5 <- lm(f, d)

mods  <- list(m1, m2, m3, m4, m5)
coef  <- list(m1 = mod_cred$coef, m2 = mod_main$coef, m3 = mod_indep$coef,
              m4 = mod_dpp$coef, m5 = mod_kmt$coef)
se    <- list(m1 = mod_cred$se, m2 = mod_main$se, m3 = mod_indep$se,
              m4 = mod_dpp$se, m5 = mod_kmt$se)
p     <- list(m1 = mod_cred$p, m2 = mod_main$p, m3 = mod_indep$p,
              m4 = mod_dpp$p, m5 = mod_kmt$p)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Credibility', 'Mainland', 'Independence', 'DPP', 'KMT')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB5.tex', out.header = T)

df <- dfmain

##### Compute results for Table B.6; ordered logistic regression #####
dft <- df
dft$income <- na_if(dft$income, 98)
dft$nat_id <- recode(dft$nat_id, '1' = 1, '2' = 0, '3' = 0, '98' = 0)

# Effect on Mainland Government Approval
mod1 <- polr(as.factor(app_main) ~ I(group==2) + I(group==3) + pan_green +
               pan_blue + age + gender + income + education + nat_id,
             data = dft)
# Effect on Independence Approval
mod2 <- polr(as.factor(app_indep) ~ I(group==2) + I(group==3) + pan_green +
               pan_blue + age + gender + income + education + nat_id,
             data = dft)
# Effect on DPP Approval
mod3 <- polr(as.factor(app_dpp) ~ I(group==2) + I(group==3) + pan_green +
               pan_blue + age + gender + income + education + nat_id,
             data = dft)
# Effect on KMT Approval
mod4 <- polr(as.factor(app_kmt) ~ I(group==2) + I(group==3) + pan_green +
               pan_blue + age + gender + income + education + nat_id,
             data = dft)

# Create table
column.labels <- c('Mainland', 'Independence', 'DPP', 'KMT')
covariate.labels <- c('Rumor', 'Rebuttal')
omit <- c('pan_green', 'pan_blue', 'age', 'gender', 'income',
          'education', 'nat_id', 'Constant')
omit.stat <- c('adj.rsq', 'f', 'ser')
stargazer(mod1, mod2, mod3, mod4, column.labels = column.labels,
          covariate.labels = covariate.labels, dep.var.caption = '',
          dep.var.labels.include = F, model.numbers = F, omit = omit,
          omit.stat = omit.stat, out = 'tableB6.tex', out.header = T)

##### Compute results for Table B.7; effect on mainland, excl. imbalance #####
dft <- df
dft$income <- na_if(dft$income, 98)
dft$nat_id <- recode(dft$nat_id, '1' = 1, '2' = 0, '3' = 0, '98' = 0)

# Effect on Mainland Government Approval
mod1 <- lm(app_main ~ I(group==2) + I(group==3) + age + gender + income +
             education, data = dft)

# Create table
column.labels <- c('Mainland')
covariate.labels <- c('Rumor', 'Rebuttal')
omit <- c('age', 'gender', 'income', 'education', 'Constant')
omit.stat <- c('adj.rsq', 'f', 'ser')
stargazer(mod1, column.labels = column.labels,
          covariate.labels = covariate.labels, dep.var.caption = '',
          dep.var.labels.include = F, model.numbers = F, omit = omit,
          omit.stat = omit.stat, out = 'tableB7.tex', out.header = T)


##### Compute results for Table B.8; interaction effects #####
dft <- df
dft$income <- na_if(dft$income, 98)
dft$nat_id <- recode(dft$nat_id, '1' = 1, '2' = 0, '3' = 0, '98' = 0)

# Effect on Mainland Government Approval
mod1 <- lm(app_main ~ (I(group==2) + I(group==3)) * (pan_green + pan_blue) +
             age + gender + income + education + nat_id, data = dft)
# Effect on Independence Approval
mod2 <- lm(app_indep ~ (I(group==2) + I(group==3)) * (pan_green + pan_blue) +
             age + gender + income + education + nat_id, data = dft)
# Effect on DPP Approval
mod3 <- lm(app_dpp ~ (I(group==2) + I(group==3)) * (pan_green + pan_blue) +
             age + gender + income + education + nat_id, data = dft)
# Effect on KMT Approval
mod4 <- lm(app_kmt ~ (I(group==2) + I(group==3)) * (pan_green + pan_blue) +
             age +  gender + income + education + nat_id, data = dft)

# Create table
column.labels <- c('Mainland', 'Independence', 'DPP', 'KMT')
covariate.labels <- c('Rumor', 'Rebuttal', 'Pan-Green', 'Pan-Blue',
                      'Rumor * Pan-Green', 'Rumor * Pan-Blue',
                      'Rebuttal * Pan-Green', 'Rebuttal * Pan-Blue')
omit <- c('age', 'gender', 'income', 'education', 'nat_id', 'Constant')
omit.stat <- c('adj.rsq', 'f', 'ser')
stargazer(mod1, mod2, mod3, mod4, column.labels = column.labels,
          covariate.labels = covariate.labels, dep.var.caption = '',
          dep.var.labels.include = F, model.numbers = F, omit = omit,
          omit.stat = omit.stat, out = 'tableB7.tex', out.header = T)



##### Compute results for Table B.9; rumors negatively affect views #####
dft            <- df
dft$view_main1 <- recode(dft$view_main1, '1' = 0, '2' = 1, '3' = 0, '98' = 0)
dft$view_twgov <- recode(dft$view_twgov, '1' = 0, '2' = 1, '3' = 0, '98' = 0)

# Affect views of mainland
## Full Sample
mod1f <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(view_main1 ~ group, data = dft, condition1 = 2,
            condition2 = 3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(view_main1 ~ group, data = dft, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(view_main1 ~ group, data = dft, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(view_main1 ~ group, data = dft, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_main1 <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))

# Affect views of Taiwanese government
## Full Sample
mod1f <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 2) # Rumor - Control
mod2f <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 3) # Rebuttal - Control
mod3f <- dm(view_twgov ~ group, data = dft, condition1=2,
            condition2=3) # Rebuttal - Rumor
## Pan-Green
mod1g <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 2, subset = pan_green==1) # Rumor - Control
mod2g <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Control
mod3g <- dm(view_twgov ~ group, data = dft, condition1 = 2,
            condition2 = 3, subset = pan_green==1) # Rebuttal - Rumor
## Pan-Blue
mod1b <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 2, subset = pan_blue==1) # Rumor - Control
mod2b <- dm(view_twgov ~ group, data = dft, condition1 = 1,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Control
mod3b <- dm(view_twgov ~ group, data = dft, condition1 = 2,
            condition2 = 3, subset = pan_blue==1) # Rebuttal - Rumor

mod_twgov <- combine_models(list(mod1f, mod2f, mod3f, mod1g, mod2g, mod3g,
                                 mod1b, mod2b, mod3b))


# Create table
## Prepare for stargazer
regressors  <- c('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i')
d           <- as.data.frame(matrix(rnorm(20 * 9), nc = 10))
names(d)    <- c('dv', regressors)
f           <- as.formula(paste('dv', '~ 0 +',
                                paste(regressors, collapse = '+')))
m1 <- m2 <- lm(f, d)

mods  <- list(m1, m2)
coef  <- list(m1 = mod_main1$coef, m2 = mod_twgov$coef)
se    <- list(m1 = mod_main1$se, m2 = mod_twgov$se)
p     <- list(m1 = mod_main1$p, m2 = mod_twgov$p)

covariate.labels <- c('Rumor vs Control (F)', 'Rebuttal vs Control (F)',
                      'Rebuttal vs Rumor (F)', 'Rumor vs Control (G)',
                      'Rebuttal vs Control (G)', 'Rebuttal vs Rumor (G)',
                      'Rumor vs Control (B)', 'Rebuttal vs Control (B)',
                      'Rebuttal vs Rumor (B)')
column.labels    <- c('Mainland', 'TW Goverment')
stargazer(mods, coef = coef, se = se, p = p,
          covariate.labels = covariate.labels, column.labels = column.labels,
          dep.var.caption = '', dep.var.labels.include = F, model.numbers = F,
          omit.stat = 'all', out = 'tableB8.tex', out.header = T)